Module: Aws::Route53Profiles
- Defined in:
- lib/aws-sdk-route53profiles/endpoint_parameters.rb,
sig/client.rbs,
sig/errors.rbs,
sig/waiters.rbs,
sig/resource.rbs,
lib/aws-sdk-route53profiles/plugins/endpoints.rb,
lib/aws-sdk-route53profiles/endpoint_provider.rb,
lib/aws-sdk-route53profiles/client_api.rb,
lib/aws-sdk-route53profiles/endpoints.rb,
lib/aws-sdk-route53profiles/resource.rb,
lib/aws-sdk-route53profiles/errors.rb,
lib/aws-sdk-route53profiles/client.rb,
lib/aws-sdk-route53profiles/types.rb,
lib/aws-sdk-route53profiles.rb
Overview
This module provides support for Route 53 Profiles. This module is available in the
aws-sdk-route53profiles gem.
Client
The Client class provides one method for each API operation. Operation methods each accept a hash of request parameters and return a response structure.
route_53_profiles = Aws::Route53Profiles::Client.new
resp = route_53_profiles.associate_profile(params)
See Client for more information.
Errors
Errors returned from Route 53 Profiles are defined in the Errors module and all extend Errors::ServiceError.
begin
# do stuff
rescue Aws::Route53Profiles::Errors::ServiceError
# rescues all Route 53 Profiles API errors
end
See Errors for more information.
Defined Under Namespace
Modules: ClientApi, Endpoints, Errors, Plugins, Types, Waiters Classes: Client, EndpointParameters, EndpointProvider, Resource
service collapse
- GEM_VERSION =
'1.37.0'