Class: Aws::Route53Profiles::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Route53Profiles::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-route53profiles/client.rb,
sig/client.rbs
Overview
An API client for Route53Profiles. To construct a client, you need to configure a :region and :credentials.
client = Aws::Route53Profiles::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AssociateProfileResponseSuccess, _AssociateResourceToProfileResponseSuccess, _CreateProfileResponseSuccess, _DeleteProfileResponseSuccess, _DisassociateProfileResponseSuccess, _DisassociateResourceFromProfileResponseSuccess, _GetProfileAssociationResponseSuccess, _GetProfileResourceAssociationResponseSuccess, _GetProfileResponseSuccess, _ListProfileAssociationsResponseSuccess, _ListProfileResourceAssociationsResponseSuccess, _ListProfilesResponseSuccess, _ListTagsForResourceResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateProfileResourceAssociationResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_profile(params = {}) ⇒ Types::AssociateProfileResponse
Associates a Route 53 Profiles profile with a VPC.
-
#associate_resource_to_profile(params = {}) ⇒ Types::AssociateResourceToProfileResponse
Associates a DNS reource configuration to a Route 53 Profile.
-
#create_profile(params = {}) ⇒ Types::CreateProfileResponse
Creates an empty Route 53 Profile.
-
#delete_profile(params = {}) ⇒ Types::DeleteProfileResponse
Deletes the specified Route 53 Profile.
-
#disassociate_profile(params = {}) ⇒ Types::DisassociateProfileResponse
Dissociates a specified Route 53 Profile from the specified VPC.
-
#disassociate_resource_from_profile(params = {}) ⇒ Types::DisassociateResourceFromProfileResponse
Dissoaciated a specified resource, from the Route 53 Profile.
-
#get_profile(params = {}) ⇒ Types::GetProfileResponse
Returns information about a specified Route 53 Profile, such as whether whether the Profile is shared, and the current status of the Profile.
-
#get_profile_association(params = {}) ⇒ Types::GetProfileAssociationResponse
Retrieves a Route 53 Profile association for a VPC.
-
#get_profile_resource_association(params = {}) ⇒ Types::GetProfileResourceAssociationResponse
Returns information about a specified Route 53 Profile resource association.
-
#list_profile_associations(params = {}) ⇒ Types::ListProfileAssociationsResponse
Lists all the VPCs that the specified Route 53 Profile is associated with.
-
#list_profile_resource_associations(params = {}) ⇒ Types::ListProfileResourceAssociationsResponse
Lists all the resource associations for the specified Route 53 Profile.
-
#list_profiles(params = {}) ⇒ Types::ListProfilesResponse
Lists all the Route 53 Profiles associated with your Amazon Web Services account.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags that you associated with the specified resource.
-
#tag_resource(params = {}) ⇒ Struct
Adds one or more tags to a specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from a specified resource.
-
#update_profile_resource_association(params = {}) ⇒ Types::UpdateProfileResourceAssociationResponse
Updates the specified Route 53 Profile resourse association.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-route53profiles/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1242 1243 1244 |
# File 'lib/aws-sdk-route53profiles/client.rb', line 1242 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1245 1246 1247 |
# File 'lib/aws-sdk-route53profiles/client.rb', line 1245 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#associate_profile(params = {}) ⇒ Types::AssociateProfileResponse
Associates a Route 53 Profiles profile with a VPC. A VPC can have only one Profile associated with it, but a Profile can be associated with 1000 of VPCs (and you can request a higher quota). For more information, see https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/DNSLimitations.html#limits-api-entities.
86 |
# File 'sig/client.rbs', line 86
def associate_profile: (
|
#associate_resource_to_profile(params = {}) ⇒ Types::AssociateResourceToProfileResponse
Associates a DNS reource configuration to a Route 53 Profile.
104 |
# File 'sig/client.rbs', line 104
def associate_resource_to_profile: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1215 1216 1217 1218 1219 1220 1221 1222 1223 1224 1225 1226 1227 1228 1229 1230 1231 |
# File 'lib/aws-sdk-route53profiles/client.rb', line 1215 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Route53Profiles') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-route53profiles' context[:gem_version] = '1.37.0' Seahorse::Client::Request.new(handlers, context) end |
#create_profile(params = {}) ⇒ Types::CreateProfileResponse
Creates an empty Route 53 Profile.
117 |
# File 'sig/client.rbs', line 117
def create_profile: (
|
#delete_profile(params = {}) ⇒ Types::DeleteProfileResponse
Deletes the specified Route 53 Profile. Before you can delete a profile, you must first disassociate it from all VPCs.
134 |
# File 'sig/client.rbs', line 134
def delete_profile: (
|
#disassociate_profile(params = {}) ⇒ Types::DisassociateProfileResponse
Dissociates a specified Route 53 Profile from the specified VPC.
144 |
# File 'sig/client.rbs', line 144
def disassociate_profile: (
|
#disassociate_resource_from_profile(params = {}) ⇒ Types::DisassociateResourceFromProfileResponse
Dissoaciated a specified resource, from the Route 53 Profile.
155 |
# File 'sig/client.rbs', line 155
def disassociate_resource_from_profile: (
|
#get_profile(params = {}) ⇒ Types::GetProfileResponse
Returns information about a specified Route 53 Profile, such as whether whether the Profile is shared, and the current status of the Profile.
166 |
# File 'sig/client.rbs', line 166
def get_profile: (
|
#get_profile_association(params = {}) ⇒ Types::GetProfileAssociationResponse
Retrieves a Route 53 Profile association for a VPC. A VPC can have only one Profile association, but a Profile can be associated with up to 5000 VPCs.
176 |
# File 'sig/client.rbs', line 176
def get_profile_association: (
|
#get_profile_resource_association(params = {}) ⇒ Types::GetProfileResourceAssociationResponse
Returns information about a specified Route 53 Profile resource association.
186 |
# File 'sig/client.rbs', line 186
def get_profile_resource_association: (
|
#list_profile_associations(params = {}) ⇒ Types::ListProfileAssociationsResponse
Lists all the VPCs that the specified Route 53 Profile is associated with.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
197 |
# File 'sig/client.rbs', line 197
def list_profile_associations: (
|
#list_profile_resource_associations(params = {}) ⇒ Types::ListProfileResourceAssociationsResponse
Lists all the resource associations for the specified Route 53 Profile.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
211 |
# File 'sig/client.rbs', line 211
def list_profile_resource_associations: (
|
#list_profiles(params = {}) ⇒ Types::ListProfilesResponse
Lists all the Route 53 Profiles associated with your Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
225 |
# File 'sig/client.rbs', line 225
def list_profiles: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags that you associated with the specified resource.
236 |
# File 'sig/client.rbs', line 236
def list_tags_for_resource: (
|
#tag_resource(params = {}) ⇒ Struct
Adds one or more tags to a specified resource.
245 |
# File 'sig/client.rbs', line 245
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from a specified resource.
255 |
# File 'sig/client.rbs', line 255
def untag_resource: (
|
#update_profile_resource_association(params = {}) ⇒ Types::UpdateProfileResourceAssociationResponse
Updates the specified Route 53 Profile resourse association.
266 |
# File 'sig/client.rbs', line 266
def update_profile_resource_association: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1235 1236 1237 |
# File 'lib/aws-sdk-route53profiles/client.rb', line 1235 def waiter_names [] end |