Class: Aws::Route53Profiles::Types::ListProfilesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-route53profiles/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

The maximum number of objects that you want to return for this request. If more objects are available, in the response, a NextToken value, which you can use in a subsequent call to get the next batch of objects, is provided.

If you don’t specify a value for MaxResults, up to 100 objects are returned.



531
532
533
534
535
536
# File 'lib/aws-sdk-route53profiles/types.rb', line 531

class ListProfilesRequest < Struct.new(
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

For the first call to this list request, omit this value.

When you request a list of objects, at most the number of objects specified by MaxResults is returned. If more objects are available for retrieval, a NextToken value is returned in the response. To retrieve the next batch of objects, use the token that was returned for the prior request in your next request.



531
532
533
534
535
536
# File 'lib/aws-sdk-route53profiles/types.rb', line 531

class ListProfilesRequest < Struct.new(
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end