Class: Aws::Route53Profiles::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Route53Profiles::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-route53profiles/client.rb
Overview
An API client for Route53Profiles. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::Route53Profiles::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_profile(params = {}) ⇒ Types::AssociateProfileResponse
Associates a Route 53 Profiles profile with a VPC.
-
#associate_resource_to_profile(params = {}) ⇒ Types::AssociateResourceToProfileResponse
Associates a DNS reource configuration to a Route 53 Profile.
-
#create_profile(params = {}) ⇒ Types::CreateProfileResponse
Creates an empty Route 53 Profile.
-
#delete_profile(params = {}) ⇒ Types::DeleteProfileResponse
Deletes the specified Route 53 Profile.
-
#disassociate_profile(params = {}) ⇒ Types::DisassociateProfileResponse
Dissociates a specified Route 53 Profile from the specified VPC.
-
#disassociate_resource_from_profile(params = {}) ⇒ Types::DisassociateResourceFromProfileResponse
Dissoaciated a specified resource, from the Route 53 Profile.
-
#get_profile(params = {}) ⇒ Types::GetProfileResponse
Returns information about a specified Route 53 Profile, such as whether whether the Profile is shared, and the current status of the Profile.
-
#get_profile_association(params = {}) ⇒ Types::GetProfileAssociationResponse
Retrieves a Route 53 Profile association for a VPC.
-
#get_profile_resource_association(params = {}) ⇒ Types::GetProfileResourceAssociationResponse
Returns information about a specified Route 53 Profile resource association.
-
#list_profile_associations(params = {}) ⇒ Types::ListProfileAssociationsResponse
Lists all the VPCs that the specified Route 53 Profile is associated with.
-
#list_profile_resource_associations(params = {}) ⇒ Types::ListProfileResourceAssociationsResponse
Lists all the resource associations for the specified Route 53 Profile.
-
#list_profiles(params = {}) ⇒ Types::ListProfilesResponse
Lists all the Route 53 Profiles associated with your Amazon Web Services account.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags that you associated with the specified resource.
-
#tag_resource(params = {}) ⇒ Struct
Adds one or more tags to a specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from a specified resource.
-
#update_profile_resource_association(params = {}) ⇒ Types::UpdateProfileResourceAssociationResponse
Updates the specified Route 53 Profile resourse association.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-route53profiles/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1242 1243 1244 |
# File 'lib/aws-sdk-route53profiles/client.rb', line 1242 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1245 1246 1247 |
# File 'lib/aws-sdk-route53profiles/client.rb', line 1245 def errors_module Errors end |
Instance Method Details
#associate_profile(params = {}) ⇒ Types::AssociateProfileResponse
Associates a Route 53 Profiles profile with a VPC. A VPC can have only one Profile associated with it, but a Profile can be associated with 1000 of VPCs (and you can request a higher quota). For more information, see [docs.aws.amazon.com/Route53/latest/DeveloperGuide/DNSLimitations.html#limits-api-entities][1].
[1]: docs.aws.amazon.com/Route53/latest/DeveloperGuide/DNSLimitations.html#limits-api-entities
534 535 536 537 |
# File 'lib/aws-sdk-route53profiles/client.rb', line 534 def associate_profile(params = {}, = {}) req = build_request(:associate_profile, params) req.send_request() end |
#associate_resource_to_profile(params = {}) ⇒ Types::AssociateResourceToProfileResponse
Associates a DNS reource configuration to a Route 53 Profile.
588 589 590 591 |
# File 'lib/aws-sdk-route53profiles/client.rb', line 588 def associate_resource_to_profile(params = {}, = {}) req = build_request(:associate_resource_to_profile, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1215 1216 1217 1218 1219 1220 1221 1222 1223 1224 1225 1226 1227 1228 1229 1230 1231 |
# File 'lib/aws-sdk-route53profiles/client.rb', line 1215 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Route53Profiles') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-route53profiles' context[:gem_version] = '1.35.0' Seahorse::Client::Request.new(handlers, context) end |
#create_profile(params = {}) ⇒ Types::CreateProfileResponse
Creates an empty Route 53 Profile.
646 647 648 649 |
# File 'lib/aws-sdk-route53profiles/client.rb', line 646 def create_profile(params = {}, = {}) req = build_request(:create_profile, params) req.send_request() end |
#delete_profile(params = {}) ⇒ Types::DeleteProfileResponse
Deletes the specified Route 53 Profile. Before you can delete a profile, you must first disassociate it from all VPCs.
684 685 686 687 |
# File 'lib/aws-sdk-route53profiles/client.rb', line 684 def delete_profile(params = {}, = {}) req = build_request(:delete_profile, params) req.send_request() end |
#disassociate_profile(params = {}) ⇒ Types::DisassociateProfileResponse
Dissociates a specified Route 53 Profile from the specified VPC.
724 725 726 727 |
# File 'lib/aws-sdk-route53profiles/client.rb', line 724 def disassociate_profile(params = {}, = {}) req = build_request(:disassociate_profile, params) req.send_request() end |
#disassociate_resource_from_profile(params = {}) ⇒ Types::DisassociateResourceFromProfileResponse
Dissoaciated a specified resource, from the Route 53 Profile.
766 767 768 769 |
# File 'lib/aws-sdk-route53profiles/client.rb', line 766 def disassociate_resource_from_profile(params = {}, = {}) req = build_request(:disassociate_resource_from_profile, params) req.send_request() end |
#get_profile(params = {}) ⇒ Types::GetProfileResponse
Returns information about a specified Route 53 Profile, such as whether whether the Profile is shared, and the current status of the Profile.
805 806 807 808 |
# File 'lib/aws-sdk-route53profiles/client.rb', line 805 def get_profile(params = {}, = {}) req = build_request(:get_profile, params) req.send_request() end |
#get_profile_association(params = {}) ⇒ Types::GetProfileAssociationResponse
Retrieves a Route 53 Profile association for a VPC. A VPC can have only one Profile association, but a Profile can be associated with up to 5000 VPCs.
843 844 845 846 |
# File 'lib/aws-sdk-route53profiles/client.rb', line 843 def get_profile_association(params = {}, = {}) req = build_request(:get_profile_association, params) req.send_request() end |
#get_profile_resource_association(params = {}) ⇒ Types::GetProfileResourceAssociationResponse
Returns information about a specified Route 53 Profile resource association.
883 884 885 886 |
# File 'lib/aws-sdk-route53profiles/client.rb', line 883 def get_profile_resource_association(params = {}, = {}) req = build_request(:get_profile_resource_association, params) req.send_request() end |
#list_profile_associations(params = {}) ⇒ Types::ListProfileAssociationsResponse
Lists all the VPCs that the specified Route 53 Profile is associated with.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
949 950 951 952 |
# File 'lib/aws-sdk-route53profiles/client.rb', line 949 def list_profile_associations(params = {}, = {}) req = build_request(:list_profile_associations, params) req.send_request() end |
#list_profile_resource_associations(params = {}) ⇒ Types::ListProfileResourceAssociationsResponse
Lists all the resource associations for the specified Route 53 Profile.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1017 1018 1019 1020 |
# File 'lib/aws-sdk-route53profiles/client.rb', line 1017 def list_profile_resource_associations(params = {}, = {}) req = build_request(:list_profile_resource_associations, params) req.send_request() end |
#list_profiles(params = {}) ⇒ Types::ListProfilesResponse
Lists all the Route 53 Profiles associated with your Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1070 1071 1072 1073 |
# File 'lib/aws-sdk-route53profiles/client.rb', line 1070 def list_profiles(params = {}, = {}) req = build_request(:list_profiles, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags that you associated with the specified resource.
1100 1101 1102 1103 |
# File 'lib/aws-sdk-route53profiles/client.rb', line 1100 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds one or more tags to a specified resource.
1129 1130 1131 1132 |
# File 'lib/aws-sdk-route53profiles/client.rb', line 1129 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from a specified resource.
1156 1157 1158 1159 |
# File 'lib/aws-sdk-route53profiles/client.rb', line 1156 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_profile_resource_association(params = {}) ⇒ Types::UpdateProfileResourceAssociationResponse
Updates the specified Route 53 Profile resourse association.
1206 1207 1208 1209 |
# File 'lib/aws-sdk-route53profiles/client.rb', line 1206 def update_profile_resource_association(params = {}, = {}) req = build_request(:update_profile_resource_association, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1235 1236 1237 |
# File 'lib/aws-sdk-route53profiles/client.rb', line 1235 def waiter_names [] end |